@@ -24,8 +24,8 @@
  *       the existing class tests in tact for a higher-level test.
  */
 
-var util    = require( __dirname + '/util' ),
-    warn    = require( __dirname + '/warn' ),
+var util    = require( './util' ),
+    warn    = require( './warn' ),
     Warning = warn.Warning,
 
     hasOwn = Object.prototype.hasOwnProperty,
@@ -244,37 +244,42 @@ exports.isInstanceOf = function( type, instance )
         return false;
     }
 
-    // check prototype chain (will throw an error if type is not a
-    // constructor (function)
-    if ( ( typeof type === 'function' )
-        && ( instance instanceof type )
-    )
-    {
-        return true;
-    }
+    // defer check to type, falling back to a more primitive check; this
+    // also allows extending ease.js' type system
+    return !!( type.__isInstanceOf || _instChk )( type, instance );
+}
 
-    // if no metadata is available, then our remaining checks cannot be
-    // performed
-    if ( !instance.__cid || !( meta = exports.getMeta( instance ) ) )
-    {
-        return false;
-    }
 
-    implemented = meta.implemented;
-    i           = implemented.length;
-
-    // check implemented interfaces et. al. (other systems may make use of
-    // this meta-attribute to provide references to types)
-    while ( i-- )
+/**
+ * Wrapper around ECMAScript instanceof check
+ *
+ * This will not throw an error if TYPE is not a function.
+ *
+ * Note that a try/catch is used instead of checking first to see if TYPE is
+ * a function; this is due to the implementation of, notably, IE, which
+ * allows instanceof to be used on some DOM objects with typeof `object'.
+ * These same objects have typeof `function' in other browsers.
+ *
+ * @param  {*}       type      constructor to check against
+ * @param  {Object}  instance  instance to examine
+ *
+ * @return  {boolean}  whether INSTANCE is an instance of TYPE
+ */
+function _instChk( type, instance )
+{
+    try
     {
-        if ( implemented[ i ] === type )
+        // check prototype chain (will throw an error if type is not a
+        // constructor)
+        if ( instance instanceof type )
         {
             return true;
         }
     }
+    catch ( e ) {}
 
     return false;
-};
+}
 
 
 /**
@@ -294,6 +299,8 @@ exports.isInstanceOf = function( type, instance )
  */
 exports.prototype.build = function extend( _, __ )
 {
+    var build = this;
+
     // ensure we'll be permitted to instantiate abstract classes for the base
     this._extending = true;
 
@@ -355,6 +362,14 @@ exports.prototype.build = function extend( _, __ )
     // increment class identifier
     this._classId++;
 
+    // if we are inheriting from a prototype, we must make sure that all
+    // properties initialized by the ctor are implicitly public; otherwise,
+    // proxying will fail to take place
+    if ( !( prototype instanceof exports.ClassBase ) )
+    {
+        this._discoverProtoProps( prototype, prop_init );
+    }
+
     // build the various class components (XXX: this is temporary; needs
     // refactoring)
     try
@@ -432,6 +447,16 @@ exports.prototype.build = function extend( _, __ )
     attachAbstract( new_class, abstract_methods );
     attachId( new_class, this._classId );
 
+    // returns a new instance of the class without invoking the constructor
+    // (intended for use in prototype chains)
+    new_class.asPrototype = function()
+    {
+        build._extending = true;
+        var inst = new_class();
+        build._extending = false;
+        return inst;
+    };
+
     // we're done with the extension process
     this._extending = false;
 
@@ -460,6 +485,55 @@ exports.prototype._getBase = function( base )
 };
 
 
+/**
+ * Discovers public properties on the given object and create an associated
+ * property
+ *
+ * This allows inheriting from a prototype that uses properties by ensuring
+ * that we properly proxy to that property. Otherwise, assigning the value
+ * on the private visibilit object would mask the underlying value rather
+ * than modifying it, leading to an inconsistent and incorrect state.
+ *
+ * This assumes that the object has already been initialized with all the
+ * properties. This may not be the case if the prototype constructor does
+ * not do so, in which case there is nothing we can do.
+ *
+ * This does not recurse on the prototype chian.
+ *
+ * For a more detailed description of this issue, see the interoperability
+ * test case for classes.
+ *
+ * @param  {Object}  obj        object from which to gather properties
+ * @param  {Object}  prop_init  destination property object
+ *
+ * @return  {undefined}
+ */
+exports.prototype._discoverProtoProps = function( obj, prop_init )
+{
+    var hasOwn = Object.hasOwnProperty,
+        pub    = prop_init[ 'public' ];
+
+    for ( var field in obj )
+    {
+        var value = obj[ field ];
+
+        // we are not interested in the objtype chain, nor are we
+        // interested in functions (which are methods and need not be
+        // proxied)
+        if ( !( hasOwn.call( obj, field ) )
+            || typeof value === 'function'
+        )
+        {
+            continue;
+        }
+
+        this._memberBuilder.buildProp(
+            prop_init, null, field, value, {}
+        );
+    }
+};
+
+
 exports.prototype.buildMembers = function buildMembers(
     props, class_id, base, prop_init, memberdest, staticInstLookup
 )
