@@ -22,7 +22,7 @@
 /**
  * Supertype
  */
-var MemberBuilder = require( __dirname + '/MemberBuilder' );
+var MemberBuilder = require( './MemberBuilder' );
 
 /**
  * Responsible for building class members
