@@ -29,8 +29,8 @@
  * keywords ]. Decide on a common format.
  */
 
-var util       = require( __dirname + '/util' ),
-    Warning    = require( __dirname + '/warn' ).Warning,
+var util       = require( './util' ),
+    Warning    = require( './warn' ).Warning,
     visibility = [ 'public', 'protected', 'private' ]
 ;
 
@@ -120,11 +120,16 @@ exports.buildMethod = function(
     members, meta, name, value, keywords, instCallback, cid, base, state
 )
 {
+    // these defaults will be used whenever a keyword set is unavailable,
+    // which should only ever be the case if we're inheriting from a
+    // prototype rather than an ease.js class/etc
+    var kdefaults = this._methodKeywordDefaults;
+
     // TODO: We can improve performance by not scanning each one individually
     // every time this method is called
     var prev_data     = scanMembers( members, name, base ),
         prev          = ( prev_data ) ? prev_data.member : null,
-        prev_keywords = ( prev && prev.___$$keywords$$ ),
+        prev_keywords = ( prev && ( prev.___$$keywords$$ || kdefaults ) ),
         dest          = getMemberVisibility( members, keywords, name );
     ;
 
@@ -194,6 +199,13 @@ exports.buildMethod = function(
 };
 
 
+/**
+ * Default keywords to apply to methods inherited from a prototype.
+ * @type  {Object}
+ */
+exports._methodKeywordDefaults = { 'virtual': true };
+
+
 /**
  * Creates an abstract override super method proxy to NAME
  *
