@@ -19,9 +19,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-var AbstractClass = require( __dirname + '/class_abstract' ),
-    ClassBuilder  = require( __dirname + '/ClassBuilder' );
-
+var AbstractClass = require( './class_abstract' ),
+    ClassBuilder  = require( './ClassBuilder' ),
+    Interface     = require( './interface' );
 
 /**
  * Trait constructor / base object
@@ -36,17 +36,22 @@ function Trait()
 {
     switch ( arguments.length )
     {
+        case 0:
+            throw Error( "Missing trait name or definition" );
+
         case 1:
-            return Trait.extend.apply( this, arguments );
-            break;
+            return ( typeof arguments[ 0 ] === 'string' )
+                ? _createStaging.apply( this, arguments )
+                : Trait.extend.apply( this, arguments );
 
         case 2:
             return createNamedTrait.apply( this, arguments );
-            break;
-
-        default:
-            throw Error( "Missing trait name or definition" );
     }
+
+    throw Error(
+        "Expecting at most two arguments for definition of named " +
+            "Trait " + name + "'; " + arguments.length + " given"
+    );
 };
 
 
@@ -60,14 +65,6 @@ function Trait()
  */
 function createNamedTrait( name, dfn )
 {
-    if ( arguments.length > 2 )
-    {
-        throw Error(
-            "Expecting at most two arguments for definition of named " +
-                "Trait " + name + "'; " + arguments.length + " given"
-        );
-    }
-
     if ( typeof name !== 'string' )
     {
         throw Error(
@@ -76,11 +73,26 @@ function createNamedTrait( name, dfn )
     }
 
     dfn.__name = name;
-
     return Trait.extend( dfn );
 }
 
 
+function _createStaging( name )
+{
+    return {
+        extend: function( dfn )
+        {
+            return createNamedTrait( name, dfn );
+        },
+
+        implement: function()
+        {
+            return createImplement( arguments, name );
+        },
+    };
+}
+
+
 Trait.extend = function( dfn )
 {
     // we may have been passed some additional metadata
@@ -139,6 +151,9 @@ Trait.extend = function( dfn )
         mixinImpl( tclass, dest_meta );
     };
 
+    // TODO: this and the above should use util.defineSecureProp
+    TraitType.__isInstanceOf = Interface.isInstanceOf;
+
     return TraitType;
 };
 
@@ -244,19 +259,37 @@ function _parseGetSet( name, value, keywords, h )
  */
 Trait.implement = function()
 {
-    var ifaces = arguments;
+    return createImplement( arguments );
+};
 
+
+/**
+ * Create a staging object from which a trait implementing a set of
+ * interfaces may be defined
+ *
+ * @param  {...Function}  interfaces  interfaces to implement
+ * @param  {string=}      name        optional trait name
+ *
+ * @return  {Object}  staged trait object
+ */
+function createImplement( ifaces, name )
+{
     return {
-        extend: function()
+        extend: function( dfn )
         {
+            if ( name )
+            {
+                dfn.__name = name;
+            }
+
             // pass our interface metadata as the invocation context
-            return Trait.extend.apply(
+            return Trait.extend.call(
                 { __$$meta: { ifaces: ifaces } },
-                arguments
+                dfn
             );
         },
     };
-};
+}
 
 
 /**
