@@ -23,12 +23,12 @@
  */
 
 // XXX: Tightly coupled
-var util = require( __dirname + '/util' ),
+var util = require( './util' ),
 
-    VisibilityObjectFactory = require( __dirname + '/VisibilityObjectFactory' ),
+    VisibilityObjectFactory = require( './VisibilityObjectFactory' ),
 
     FallbackVisibilityObjectFactory =
-        require( __dirname + '/FallbackVisibilityObjectFactory' )
+        require( './FallbackVisibilityObjectFactory' )
 ;
 
 
