@@ -19,28 +19,28 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-var util         = require( __dirname + '/util' ),
-    ClassBuilder = require( __dirname + '/ClassBuilder' ),
+var util         = require( './util' ),
+    ClassBuilder = require( './ClassBuilder' ),
 
-    warn    = require( __dirname + '/warn' ),
+    warn    = require( './warn' ),
     Warning = warn.Warning,
 
-    MethodWrapperFactory = require( __dirname + '/MethodWrapperFactory' ),
-    wrappers             = require( __dirname + '/MethodWrappers' ).standard,
+    MethodWrapperFactory = require( './MethodWrapperFactory' ),
+    wrappers             = require( './MethodWrappers' ).standard,
 
     class_builder = ClassBuilder(
-        require( __dirname + '/MemberBuilder' )(
+        require( './MemberBuilder' )(
             MethodWrapperFactory( wrappers.wrapNew ),
             MethodWrapperFactory( wrappers.wrapOverride ),
             MethodWrapperFactory( wrappers.wrapProxy ),
-            require( __dirname + '/MemberBuilderValidator' )(
+            require( './MemberBuilderValidator' )(
                 function( warning )
                 {
                     warn.handle( Warning( warning ) );
                 }
             )
         ),
-        require( __dirname + '/VisibilityObjectFactoryFactory' )
+        require( './VisibilityObjectFactoryFactory' )
             .fromEnvironment()
     )
 ;
