@@ -23,7 +23,7 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-var Class = require( __dirname + '/class' );
+var Class = require( './class' );
 
 
 /**
