@@ -19,20 +19,20 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-var util           = require( __dirname + '/util' ),
+var util           = require( './util' ),
 
-    MethodWrapperFactory = require( __dirname + '/MethodWrapperFactory' ),
-    wrappers             = require( __dirname + '/MethodWrappers' ).standard,
+    MethodWrapperFactory = require( './MethodWrapperFactory' ),
+    wrappers             = require( './MethodWrappers' ).standard,
 
-    member_builder = require( __dirname + '/MemberBuilder' )(
+    member_builder = require( './MemberBuilder' )(
         MethodWrapperFactory( wrappers.wrapNew ),
         MethodWrapperFactory( wrappers.wrapOverride ),
         MethodWrapperFactory( wrappers.wrapProxy ),
-        require( __dirname + '/MemberBuilderValidator' )()
+        require( './MemberBuilderValidator' )()
     ),
 
-    Class = require( __dirname + '/class' )
-;
+    Class        = require( './class' ),
+    ClassBuilder = require( './ClassBuilder' );;
 
 
 /**
@@ -268,6 +268,8 @@ var extend = ( function( extending )
 
         attachExtend( new_interface );
         attachStringMethod( new_interface, iname );
+        attachCompat( new_interface );
+        attachInstanceOf( new_interface );
 
         new_interface.prototype   = prototype;
         new_interface.constructor = new_interface;
@@ -376,3 +378,142 @@ function attachStringMethod( func, iname )
     ;
 }
 
+
+/**
+ * Attaches a method to assert whether a given object is compatible with the
+ * interface
+ *
+ * @param  {Function}  iface  interface to attach method to
+ *
+ * @return  {undefined}
+ */
+function attachCompat( iface )
+{
+    util.defineSecureProp( iface, 'isCompatible', function( obj )
+    {
+        return isCompat( iface, obj );
+    } );
+}
+
+
+/**
+ * Determines if the given object is compatible with the given interface.
+ *
+ * An object is compatible if it defines all methods required by the
+ * interface, with at least the required number of parameters.
+ *
+ * Processing time is linear with respect to the number of members of the
+ * provided interface.
+ *
+ * To get the actual reasons in the event of a compatibility failure, use
+ * analyzeCompat instead.
+ *
+ * @param  {Interface}  iface  interface that must be adhered to
+ * @param  {Object}     obj    object to check compatibility against
+ *
+ * @return  {boolean}  true if compatible, otherwise false
+ */
+function isCompat( iface, obj )
+{
+    // yes, this processes the entire interface, but it is hopefully small
+    // anyway and the process is fast enough that doing otherwise may be
+    // micro-optimizing
+    return analyzeCompat( iface, obj ).length === 0;
+}
+
+
+/**
+ * Analyzes the given object to determine if there exists any compatibility
+ * issues with respect to the given interface
+ *
+ * Will provide an array of the names of incompatible members. A method is
+ * incompatible if it is not defined or if it does not define at least the
+ * required number of parameters.
+ *
+ * Processing time is linear with respect to the number of members of the
+ * provided interface.
+ *
+ * @param  {Interface}  iface  interface that must be adhered to
+ * @param  {Object}     obj    object to check compatibility against
+ *
+ * @return  {Array.<Array.<string, string>>}  compatibility reasons
+ */
+function analyzeCompat( iface, obj )
+{
+    var missing = [];
+
+    util.propParse( iface.prototype, {
+        method: function( name, func, is_abstract, keywords )
+        {
+            if ( typeof obj[ name ] !== 'function' )
+            {
+                missing.push( [ name, 'missing' ] );
+            }
+            else if ( obj[ name ].length < func.__length )
+            {
+                // missing parameter(s); note that we check __length on the
+                // interface method (our internal length) but not on the
+                // object (since it may be a vanilla object)
+                missing.push( [ name, 'incompatible' ] );
+            }
+        },
+    } );
+
+    return missing;
+}
+
+
+/**
+ * Attaches instance check method
+ *
+ * This method is invoked when checking the type of a class against an
+ * interface.
+ *
+ * @param  {Interface}  iface  interface that must be adhered to
+ *
+ * @return  {undefined}
+ */
+function attachInstanceOf( iface )
+{
+    util.defineSecureProp( iface, '__isInstanceOf', function( type, obj )
+    {
+        return _isInstanceOf( type, obj );
+    } );
+}
+
+
+/**
+ * Determine if INSTANCE implements the interface TYPE
+ *
+ * @param  {Interface}  type      interface to check against
+ * @param  {Object}     instance  instance to examine
+ *
+ * @return  {boolean}  whether TYPE is implemented by INSTANCE
+ */
+function _isInstanceOf( type, instance )
+{
+    // if no metadata are available, then our remaining checks cannot be
+    // performed
+    if ( !instance.__cid || !( meta = ClassBuilder.getMeta( instance ) ) )
+    {
+        return false;
+    }
+
+    implemented = meta.implemented;
+    i           = implemented.length;
+
+    // check implemented interfaces et. al. (other systems may make use of
+    // this meta-attribute to provide references to types)
+    while ( i-- )
+    {
+        if ( implemented[ i ] === type )
+        {
+            return true;
+        }
+    }
+
+    return false;
+}
+
+module.exports.isInstanceOf = _isInstanceOf;
+
