@@ -19,7 +19,7 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-var propParseKeywords = require( __dirname + '/prop_parser' ).parseKeywords;
+var propParseKeywords = require( './prop_parser' ).parseKeywords;
 
 
 /**
